@@ -28,8 +28,7 @@ def entrypoint(module_name: str) -> None:
 
     :param module_name: An importable :term:`Legacy Module`.
     """
-    sys.argv.extend(["--legacy", module_name])
-    main_func()
+    main_func(module_name)
 
 
 def formatwarning(message, category, filename, lineno, line=""):
