@@ -31,6 +31,7 @@ from slidge.core.pubsub import PubSubComponent
 from slidge.core.session import BaseSession
 from slidge.db import GatewayUser, SlidgeStore
 from slidge.db.avatar import avatar_cache
+from slidge.slixfix import PrivilegedIqError
 from slidge.slixfix.delivery_receipt import DeliveryReceipt
 from slidge.slixfix.roster import RosterBackend
 from slidge.util import ABCSubclassableOnceAtMost
@@ -474,11 +475,12 @@ class BaseGateway(
                 "create the MDS node of %s",
                 user_jid,
             )
-        except (IqError, IqTimeout) as e:
+        except PrivilegedIqError as exc:
+            nested = exc.nested_error()
             # conflict this means the node already exists, we can ignore that
-            if e.condition != "conflict":
+            if nested is not None and nested.condition != "conflict":
                 log.exception(
-                    "Could not create the MDS node of %s", user_jid, exc_info=e
+                    "Could not create the MDS node of %s", user_jid, exc_info=exc
                 )
         except Exception as e:
             log.exception(
