@@ -46,7 +46,7 @@ class AttachmentMixin(TextMessageMixin):
         file_path: Path,
         file_name: Optional[str] = None,
         content_type: Optional[str] = None,
-    ):
+    ) -> str | None:
         if file_name and file_path.name != file_name:
             d = Path(tempfile.mkdtemp())
             temp = d / file_name
@@ -215,7 +215,7 @@ class AttachmentMixin(TextMessageMixin):
         else:
             local_path = file_path
             new_url = await self.__upload(file_path, file_name, content_type)
-        if legacy_file_id:
+        if legacy_file_id and new_url is not None:
             self.__store.set_url(self.session.user_pk, str(legacy_file_id), new_url)
 
         return is_temp, local_path, new_url
