@@ -11,7 +11,7 @@ from slixmpp import (
     StanzaPath,
     register_stanza_plugin,
 )
-from slixmpp.exceptions import XMPPError
+from slixmpp.exceptions import IqError, IqTimeout, XMPPError
 from slixmpp.plugins.base import BasePlugin, register_plugin
 from slixmpp.plugins.xep_0060.stanza import Event, EventItem, EventItems, Item
 from slixmpp.plugins.xep_0084 import Data as AvatarData
@@ -134,7 +134,11 @@ class PubSubComponent(NamedLockMixin, BasePlugin):
             info = None
         if info is None:
             async with self.lock(from_):
-                iq = await self.xmpp.plugin["xep_0030"].get_info(from_)
+                try:
+                    iq = await self.xmpp.plugin["xep_0030"].get_info(from_)
+                except (IqError, IqTimeout):
+                    log.debug("Could get disco#info of %s, ignoring", from_)
+                    return []
             info = iq["disco_info"]
         return info["features"]
 
