@@ -648,7 +648,7 @@ class LegacyMUC(
             since = self.xmpp.plugin["xep_0082"].parse(history_params["since"])
         except ValueError:
             since = None
-        if seconds:
+        if seconds is not None:
             since = datetime.now() - timedelta(seconds=seconds)
         if equals_zero(maxchars) or equals_zero(maxstanzas):
             log.debug("Joining client does not want any old-school MUC history-on-join")
@@ -922,8 +922,13 @@ class LegacyMUC(
         after_id = after_id_rsm or after_id
 
         before_rsm = iq["mam"]["rsm"]["before"]
-        if before_rsm is True and max_results is not None:
+        if before_rsm is not None and max_results is not None:
             last_page_n = max_results
+            # - before_rsm is True means the empty element <before />, which means
+            #   "last page in chronological order", cf https://xmpp.org/extensions/xep-0059.html#backwards
+            # - before_rsm == "an ID" means <before>an ID</before>
+            if before_rsm is not True:
+                before_id = before_rsm
         else:
             last_page_n = None
 
