@@ -60,7 +60,7 @@ class SigTermInterrupt(Exception):
     pass
 
 
-def get_configurator():
+def get_configurator(from_entrypoint: bool = False):
     p = configargparse.ArgumentParser(
         default_config_files=os.getenv(
             "SLIDGE_CONF_DIR", "/etc/slidge/conf.d/*.conf"
@@ -98,7 +98,9 @@ def get_configurator():
         action="version",
         version=f"%(prog)s {slidge.__version__}",
     )
-    configurator = MainConfig(config, p)
+    configurator = MainConfig(
+        config, p, skip_options=("legacy_module",) if from_entrypoint else ()
+    )
     return configurator
 
 
@@ -106,8 +108,8 @@ def get_parser():
     return get_configurator().parser
 
 
-def configure():
-    configurator = get_configurator()
+def configure(from_entrypoint: bool):
+    configurator = get_configurator(from_entrypoint)
     args, unknown_argv = configurator.set_conf()
 
     if not (h := config.HOME_DIR).exists():
@@ -124,12 +126,16 @@ def handle_sigterm(_signum, _frame):
     raise SigTermInterrupt
 
 
-def main():
+def main(module_name: str | None = None) -> None:
+    from_entrypoint = module_name is not None
     signal.signal(signal.SIGTERM, handle_sigterm)
 
-    unknown_argv = configure()
+    unknown_argv = configure(from_entrypoint)
     logging.info("Starting slidge version %s", slidge.__version__)
 
+    if module_name is not None:
+        config.LEGACY_MODULE = module_name
+
     legacy_module = importlib.import_module(config.LEGACY_MODULE)
     logging.debug("Legacy module: %s", dir(legacy_module))
     logging.info(
