@@ -763,6 +763,39 @@ class TestAimShakespeareBase(Base):
         assert st["error"]["condition"] == "forbidden"
         self.xmpp.jid_validator = re.compile(".*")
 
+    def test_disco_adhoc_command_register(self):
+        self.xmpp.jid_validator = re.compile(".*@whatever.com")
+        self.recv(  # language=XML
+            f"""
+            <iq type='get'
+                from='candidate@whatever.com'
+                to='{self.xmpp.boundjid.bare}'>
+              <query xmlns='http://jabber.org/protocol/disco#items'
+                     node='http://jabber.org/protocol/commands' />
+            </iq>
+            """
+        )
+        self.send(  # language=XML
+            f"""
+            <iq type='result'
+                to='candidate@whatever.com'
+                from='{self.xmpp.boundjid.bare}'
+                id='1'>
+              <query xmlns='http://jabber.org/protocol/disco#items'
+                     node='http://jabber.org/protocol/commands'>
+                <item jid="aim.shakespeare.lit"
+                      node="{ADMINISTRATION.node}"
+                      name="{ADMINISTRATION.name}" />
+                <item jid="aim.shakespeare.lit"
+                      node="jabber:iq:register"
+                      name="📝 Register to the gateway" />
+              </query>
+            </iq>
+            """
+        )
+        self.xmpp.jid_validator = re.compile(".*")
+
+
     def test_adhoc_forbidden_non_admin(self):
         with unittest.mock.patch(
             "slixmpp.plugins.xep_0050.adhoc.XEP_0050.new_session",
